"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from polar_sdk.utils import FieldMetadata, QueryParamMetadata, SecurityMetadata
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class CustomerPortalSeatsListSeatsSecurityTypedDict(TypedDict):
    customer_session: str


class CustomerPortalSeatsListSeatsSecurity(BaseModel):
    customer_session: Annotated[
        str,
        FieldMetadata(
            security=SecurityMetadata(
                scheme=True,
                scheme_type="http",
                sub_type="bearer",
                field_name="Authorization",
            )
        ),
    ]


class CustomerPortalSeatsListSeatsRequestTypedDict(TypedDict):
    subscription_id: NotRequired[Nullable[str]]
    r"""Subscription ID"""
    order_id: NotRequired[Nullable[str]]
    r"""Order ID"""


class CustomerPortalSeatsListSeatsRequest(BaseModel):
    subscription_id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Subscription ID"""

    order_id: Annotated[
        OptionalNullable[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = UNSET
    r"""Order ID"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["subscription_id", "order_id"]
        nullable_fields = ["subscription_id", "order_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
